def getHputStats(vmanage, deviceId):
    """
    Get Appqoe Hput Statistics from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/appqoe/appqoe-hput-stats?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getNatStats(vmanage, deviceId):
    """
    Get Appqoe Nat Statistics from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/appqoe/appqoe-nat-stats?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getRmResources(vmanage, deviceId):
    """
    Get Appqoe Resource Manager resources from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/appqoe/appqoe-rm-resource?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getRMStats(vmanage, deviceId):
    """
    Get Appqoe RM Statistics from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/appqoe/appqoe-rm-stats?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getServicesStatus(vmanage, deviceId):
    """
    Get Appqoe Services Status from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/appqoe/appqoe-services-status?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getSppiPipeStats(vmanage, deviceId):
    """
    Get Appqoe Sppi Pipe Stats from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/appqoe/appqoe-sppi-pipe-resource?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getSppiQueueStats(vmanage, deviceId):
    """
    Get Appqoe Sppi Queue Stats from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/appqoe/appqoe-sppi-queue-resource?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getClusterSummary(vmanage, deviceId):
    """
    Get Appqoe Cluster Summary from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/appqoe/cluster-summary?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getErrorRecent(vmanage, deviceId):
    """
    Get Appqoe error recent from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/appqoe/error-recent?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getFlowClosedError(vmanage, deviceId):
    """
    Get Appqoe flow closed error from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/appqoe/flow-closed-error?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getServiceControllers(vmanage, deviceId):
    """
    Get Appqoe service controllers from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/appqoe/service-controllers?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getStatus(vmanage, deviceId):
    """
    Get Appqoe status from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/appqoe/status?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
