from py_viptela.api.config.assembler import security
from py_viptela.api.config.assembler import vedge
from py_viptela.api.config.assembler import voice
from py_viptela.api.config.assembler import vsmart