def getUTDDataplaneConfig(vmanage, deviceId):
    """
    Get data plane config from Device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/utd/dataplane-config?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getUTDDataplaneGlobal(vmanage, deviceId):
    """
    Get data plane global from Device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/utd/dataplane-global?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getUTDDataplaneStats(vmanage, deviceId):
    """
    Get data plane stats from Device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/utd/dataplane-stats?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getUTDDataplaneStatsSummary(vmanage, deviceId):
    """
    Get data plane stats summary
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/utd/dataplane-stats-summary?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getUTDEngineInstanceStatus(vmanage, deviceId):
    """
    Get UTD engine instance status from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/utd/engine-instance-status?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getUTDEngineStatus(vmanage, deviceId):
    """
    Get UTD engine status from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/utd/engine-status?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getUTDFileAnalysisStatus(vmanage, deviceId):
    """
    Get UTD file analysis status from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/utd/file-analysis-status?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getUTDFileReputationStatus(vmanage, deviceId):
    """
    Get UTD file reputation status from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/utd/file-reputation-status?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getUTDIpsUpdateStatus(vmanage, deviceId):
    """
    Get UTD IPS update status from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/utd/ips-update-status?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getSignatureVersionInfo(vmanage, deviceId):
    """
    Get UTD Signature version information from Device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/utd/signature/version/details?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getUTDUrlfConnectionStatus(vmanage, deviceId):
    """
    Get UTD URLF Connection status from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/utd/urlf-con-status?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getUTDUrlfUpdateStatus(vmanage, deviceId):
    """
    Get UTD URLF update status from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/utd/urlf-update-status?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getUTDVersionStatus(vmanage, deviceId):
    """
    Get UTD version status from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/utd/version-status?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
