from py_viptela.api.config.device import actions
from py_viptela.api.config.device import confighist
from py_viptela.api.config.device import fwupdate
from py_viptela.api.config.device import inventory
from py_viptela.api.config.device import proxy
from py_viptela.api.config.device import swpack
from py_viptela.api.config.device import swupdate
